<?php
/*
Plugin Name: Üyelik Formuna TC Kimlik Doğrulaması
Description: Spamlari yasal yollardan engelleyebilmek ve geçersiz bilgilerle üyelik oluşturmayı engellemek adına Wordpress blogunuzda üyelik esnasında pratik bir şekilde TC kimlik doğrulaması yapabilirsiniz.
Version: 1.0
Author: Bilhos
Author URI:  https://bilhos.com.tr
License:     GPLv2 or later
License URI: http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
*/

// Üyelik formuna ek alanları ekle
function tckn_extra_fields() {
    ?>
    <p>
        <label for="tckn">TC Kimlik No</label>
        <input type="text" name="tckn" id="tckn" required>
    </p>
    <p>
        <label for="ad">Ad</label>
        <input type="text" name="ad" id="ad" required>
    </p>
    <p>
        <label for="soyad">Soyad</label>
        <input type="text" name="soyad" id="soyad" required>
    </p>
    <p>
        <label for="dogum_yili">Doğum Yılı</label>
        <input type="text" name="dogum_yili" id="dogum_yili" required>
    </p>
    <?php
}
add_action('register_form', 'tckn_extra_fields');

// Üyelik formundaki ek alanlara girilen bilgileri doğrula
function tckn_validate_extra_fields($errors, $sanitized_user_login, $user_email) {
    if (isset($_POST['tckn']) && isset($_POST['ad']) && isset($_POST['soyad']) && isset($_POST['dogum_yili'])) {
        $tckn = $_POST['tckn'];
        $ad = $_POST['ad'];
        $soyad = $_POST['soyad'];
        $dogum_yili = $_POST['dogum_yili'];
        
        // NVİ API'sini kullanarak TC Kimlik No doğrulama işlemi
        $nvi_api_url = 'https://tckimlik.nvi.gov.tr/Service/KPSPublic.asmx?op=TCKimlikNoDogrula';
        $soap_request = '<?xml version="1.0" encoding="utf-8"?>
            <soap:Envelope xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
              <soap:Body>
                <TCKimlikNoDogrula xmlns="http://tckimlik.nvi.gov.tr/WS">
                  <TCKimlikNo>' . $tckn . '</TCKimlikNo>
                  <Ad>' . $ad . '</Ad>
                  <Soyad>' . $soyad . '</Soyad>
                  <DogumYili>' . $dogum_yili . '</DogumYili>
                </TCKimlikNoDogrula>
              </soap:Body>
            </soap:Envelope>';

        $headers = array(
            'Content-Type: text/xml; charset=utf-8',
            'Content-Length: ' . strlen($soap_request)
        );

        $curl = curl_init($nvi_api_url);
        curl_setopt($curl, CURLOPT_POST, true);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $soap_request);
        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        $response = curl_exec($curl);
        curl_close($curl);

        $xml = simplexml_load_string($response);
        $result = $xml->children('http://schemas.xmlsoap.org/soap/envelope/')->Body->children()->TCKimlikNoDogrulaResponse->TCKimlikNoDogrulaResult;

        if ($result != 'true') {
            $errors->add('tckn_error', 'Girilen TC Kimlik No doğrulanamadı.');
        }
    }

    return $errors;
}
add_filter('registration_errors', 'tckn_validate_extra_fields', 10, 3);

// Üyelik formuna girilen bilgileri kaydet
function tckn_register_extra_fields($user_id) {
    if (isset($_POST['tckn']) && isset($_POST['ad']) && isset($_POST['soyad']) && isset($_POST['dogum_yili'])) {
        $tckn = $_POST['tckn'];
        $encrypted_tckn = md5($tckn); // TC kimlik no'yu şifrele

        // TC kimlik no'yu kullanıcıyla ilişkilendirerek veritabanına kaydet
        update_user_meta($user_id, 'tckn', $encrypted_tckn);
    }
}
add_action('user_register', 'tckn_register_extra_fields');

// Aynı TC kimlik no ile üye olunmasını engelle
function tckn_prevent_duplicate_registration($errors, $sanitized_user_login, $user_email) {
    if (isset($_POST['tckn'])) {
        $tckn = $_POST['tckn'];
        $encrypted_tckn = md5($tckn); // TC kimlik no'yu şifrele

        // Veritabanında aynı TC kimlik no'ya sahip kullanıcıları kontrol et
        $existing_user = get_users(array('meta_key' => 'tckn', 'meta_value' => $encrypted_tckn));

        if (!empty($existing_user)) {
            $errors->add('tckn_duplicate_error', 'Bu TC Kimlik No ile zaten bir hesap mevcut.');
        }
    }

    return $errors;
}
add_filter('registration_errors', 'tckn_prevent_duplicate_registration', 10, 3);